@@ -6,11 +6,11 @@ a sample of the various operations that can be applied to it.
 This example prints **a lot** of text to the console.
 !*/
 
-#[cfg(feature = "alloc")]
+#[cfg(any(feature = "alloc", feature = "std"))]
 extern crate bitvec;
 
-#[cfg(feature = "alloc")]
-use bitvec::{
+#[cfg(any(feature = "alloc", feature = "std"))]
+use bitvec::prelude::{
 	//  `bitvec!` macro
 	bitvec,
 	//  trait unifying the primitives (you shouldn’t explicitly need this)
@@ -26,10 +26,10 @@ use bitvec::{
 	//  this ordering)
 	LittleEndian,
 };
-#[cfg(feature = "alloc")]
+#[cfg(any(feature = "alloc", feature = "std"))]
 use std::iter::repeat;
 
-#[cfg(feature = "alloc")]
+#[cfg(any(feature = "alloc", feature = "std"))]
 fn main() {
 	let bv = bitvec![   //  BigEndian, u8;  //  default type values
 		0, 0, 0, 0, 0, 0, 0, 1,
@@ -107,7 +107,7 @@ break your assumptions about what the memory looks like.\
 	}
 }
 
-#[cfg(not(feature = "alloc"))]
+#[cfg(not(any(feature = "alloc", feature = "std")))]
 fn main() {
 	println!("This example only runs when an allocator is present");
 }
